diff --git a/htdocs/admin/eventorganization.php b/htdocs/admin/eventorganization.php
index 44bd0b035c6..c7b698ea9eb 100644
--- a/htdocs/admin/eventorganization.php
+++ b/htdocs/admin/eventorganization.php
@@ -264,7 +264,7 @@ if ($action == 'edit') {
} elseif (preg_match('/thirdparty_type/', $val['type'])) {
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formcompany.class.php';
$formcompany = new FormCompany($db);
- print $formcompany->selectProspectCustomerType($conf->global->{$constname}, $constname);
+ print $formcompany->selectProspectCustomerType($conf->global->{$constname}, $constname, 'customerorprospect', 'form', '', 1);
} elseif ($val['type'] == 'securekey') {
print '';
if (!empty($conf->use_javascript_ajax)) {
diff --git a/htdocs/core/class/html.formcompany.class.php b/htdocs/core/class/html.formcompany.class.php
index 3e2c3588405..94ab9caf5f9 100644
--- a/htdocs/core/class/html.formcompany.class.php
+++ b/htdocs/core/class/html.formcompany.class.php
@@ -998,16 +998,16 @@ class FormCompany extends Form
/**
* Return a HTML select for thirdparty type
*
* @param int $selected selected value
* @param string $htmlname HTML select name
* @param string $htmlidname HTML select id
* @param string $typeinput HTML output
* @param string $morecss More css
* @return string HTML string
*/
- public function selectProspectCustomerType($selected, $htmlname = 'client', $htmlidname = 'customerprospect', $typeinput = 'form', $morecss = '')
+ public function selectProspectCustomerType($selected, $htmlname = 'client', $htmlidname = 'customerprospect', $typeinput = 'form', $morecss = '', $allowempty = '')
{
-
global $conf, $langs;
if (!empty($conf->global->SOCIETE_DISABLE_PROSPECTS) && !empty($conf->global->SOCIETE_DISABLE_CUSTOMERS) && empty($conf->fournisseur->enabled)) {
return '' ;
@@ -1015,8 +1015,14 @@ class FormCompany extends Form
$out = '
@@ -998,16 +998,16 @@ class FormCompany extends Form
* Return a HTML select for thirdparty type
*
- * @param int $selected selected value
- * @param string $htmlname HTML select name
- * @param string $htmlidname HTML select id
- * @param string $typeinput HTML output
- * @param string $morecss More css
- * @return string HTML string
+ * @param int $selected Selected value
+ * @param string $htmlname HTML select name
+ * @param string $htmlidname HTML select id
+ * @param string $typeinput HTML output
+ * @param string $morecss More css
+ * @param string $allowempty Allow empty value or not
+ * @return string HTML string
*/